@@ -1,7 +1,7 @@
 package Calendar::Indonesia::Holiday;
 
-our $DATE = '2017-06-20'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2017-07-31'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010001;
 use strict;
@@ -269,12 +269,10 @@ sub _jointlv {
 
 # can operate on a single holiday or multiple ones
 sub _make_tentative {
-    my ($h) = @_;
-    my $hh = ref($h) eq 'ARRAY' ? $h : [$h];
-    for (@$hh) {
-        push @{ $_->{tags} }, 'tentative' unless $_->{tags} ~~ 'tentative';
+    for my $arg (@_) {
+        push @{ $arg->{tags} }, 'tentative' unless $arg->{tags} ~~ 'tentative';
     }
-    return $h;
+    @_;
 }
 
 sub _make_jl_tentative {
@@ -623,9 +621,8 @@ my %year_holidays;
         _h_ascension ({_expand_dm("29-05")}),
 
         # sudah ditetapkan KPU tapi belum ada keppres
-        _make_tentative(
         _h_pelection ({_expand_dm("09-07")}, {}),
-        ),
+
         ($eidulf2014 =
         _h_eidulf    ({_expand_dm("28-07")}, {hyear=>1435, day=>1})),
         _h_eidulf    ({_expand_dm("29-07")}, {hyear=>1435, day=>2}),
@@ -704,27 +701,70 @@ my %year_holidays;
 # ref:
 # - https://id.wikipedia.org/wiki/2017#Hari_libur_nasional_di_Indonesia
 # - http://www.kemenkopmk.go.id/artikel/penetapan-hari-libur-nasional-dan-cuti-bersama-tahun-2017
-my $eidulf2017;
-$year_holidays{2017} = [
-    _h_chnewyear ({_expand_dm("28-01")}, {hyear=>2568}),
-    _h_nyepi     ({_expand_dm("28-03")}, {hyear=>1939}),
-    _h_goodfri   ({_expand_dm("14-04")}),
-    _h_isramiraj ({_expand_dm("24-04")}, {hyear=>1438}),
-    _h_vesakha   ({_expand_dm("11-05")}, {hyear=>2561}),
-    _h_ascension ({_expand_dm("25-05")}),
-    ($eidulf2017 =
-    _h_eidulf    ({_expand_dm("25-06")}, {hyear=>1438, day=>1})),
-    _h_eidulf    ({_expand_dm("26-06")}, {hyear=>1438, day=>2}),
-    _h_eidula    ({_expand_dm("01-09")}, {hyear=>1438}),
-    _h_hijra     ({_expand_dm("21-09")}, {hyear=>1439}),
-    _h_mawlid    ({_expand_dm("01-12")}, {hyear=>1439}),
+{
+    my $eidulf2017;
+    $year_holidays{2017} = [
+        _h_chnewyear ({_expand_dm("28-01")}, {hyear=>2568}),
+        _h_nyepi     ({_expand_dm("28-03")}, {hyear=>1939}),
+        _h_goodfri   ({_expand_dm("14-04")}),
+        _h_isramiraj ({_expand_dm("24-04")}, {hyear=>1438}),
+        _h_vesakha   ({_expand_dm("11-05")}, {hyear=>2561}),
+        _h_ascension ({_expand_dm("25-05")}),
+        ($eidulf2017 =
+        _h_eidulf    ({_expand_dm("25-06")}, {hyear=>1438, day=>1})),
+        _h_eidulf    ({_expand_dm("26-06")}, {hyear=>1438, day=>2}),
+        _h_eidula    ({_expand_dm("01-09")}, {hyear=>1438}),
+        _h_hijra     ({_expand_dm("21-09")}, {hyear=>1439}),
+        _h_mawlid    ({_expand_dm("01-12")}, {hyear=>1439}),
 
-    _jointlv     ({_expand_dm("23-06")}, {holiday=>$eidulf2017}), # ref: Keppres 18/2017 (2017-06-15)
-    _jointlv     ({_expand_dm("27-06")}, {holiday=>$eidulf2017}),
-    _jointlv     ({_expand_dm("28-06")}, {holiday=>$eidulf2017}),
-    _jointlv     ({_expand_dm("29-06")}, {holiday=>$eidulf2017}),
-    _jointlv     ({_expand_dm("30-06")}, {holiday=>$eidulf2017}),
-];
+        _jointlv     ({_expand_dm("23-06")}, {holiday=>$eidulf2017}), # ref: Keppres 18/2017 (2017-06-15)
+        _jointlv     ({_expand_dm("27-06")}, {holiday=>$eidulf2017}),
+        _jointlv     ({_expand_dm("28-06")}, {holiday=>$eidulf2017}),
+        _jointlv     ({_expand_dm("29-06")}, {holiday=>$eidulf2017}),
+        _jointlv     ({_expand_dm("30-06")}, {holiday=>$eidulf2017}),
+    ];
+}
+
+# draft
+#
+# ref:
+# - https://id.wikipedia.org/wiki/2018
+# - https://www.kemenkopmk.go.id/artikel/rakor-skb-3-menteri-tentang-hari-libur-nasional-dan-cuti-bersama-2018 (mar 13, 2017)
+{
+    my $eidulf2018;
+    $year_holidays{2018} = [
+        # - new year
+        _h_chnewyear ({_expand_dm("16-02")}, {hyear=>2569}),
+        _h_nyepi     ({_expand_dm("18-03")}, {hyear=>1940}),
+        _h_goodfri   ({_expand_dm("30-03")}),
+        _h_isramiraj ({_expand_dm("13-04")}, {hyear=>1439}),
+
+        # - labor day
+        _h_ascension ({_expand_dm("10-05")}),
+        _h_vesakha   ({_expand_dm("29-05")}, {hyear=>2562}),
+        # - pancasila day
+        ($eidulf2018 =
+        _h_eidulf    ({_expand_dm("15-06")}, {hyear=>1439, day=>1})),
+
+        _h_eidulf    ({_expand_dm("16-06")}, {hyear=>1439, day=>2}),
+        # - independence day
+        _h_eidula    ({_expand_dm("22-08")}, {hyear=>1439}),
+        _h_hijra     ({_expand_dm("12-09")}, {hyear=>1440}),
+        _h_mawlid    ({_expand_dm("20-11")}, {hyear=>1440}),
+
+        # - christmas
+
+        # note: this is currently just a wild guess because i'm having
+        # difficulty finding sources
+        _make_tentative(
+            _jointlv     ({_expand_dm("14-06")}, {holiday=>$eidulf2018}),
+            _jointlv     ({_expand_dm("18-06")}, {holiday=>$eidulf2018}),
+            _jointlv     ({_expand_dm("19-06")}, {holiday=>$eidulf2018}),
+            _jointlv     ({_expand_dm("20-06")}, {holiday=>$eidulf2018}),
+            _jointlv     ({_expand_dm("24-12")}, {holiday=>$christmas}),
+        ),
+    ];
+}
 
 
 my @years     = sort keys %year_holidays;
@@ -1050,7 +1090,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.30 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2017-06-20.
+This document describes version 0.31 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2017-07-31.
 
 =head1 SYNOPSIS
 
@@ -1142,8 +1182,8 @@ days*. If work_saturdays is set to true, Saturdays are also counted as working
 days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 2002 to 2017 (joint leave days until
-2017).
+Contains data from years 2002 to 2018 (joint leave days until
+2018).
 
 This function is not exported by default, but exportable.
 
@@ -1200,8 +1240,8 @@ days*. If work_saturdays is set to true, Saturdays are also counted as working
 days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 2002 to 2017 (joint leave days until
-2017).
+Contains data from years 2002 to 2018 (joint leave days until
+2018).
 
 This function is not exported by default, but exportable.
 
@@ -1255,8 +1295,8 @@ List Indonesian holidays in calendar.
 
 List holidays and joint leave days ("cuti bersama").
 
-Contains data from years 2002 to 2017 (joint leave days until
-2017).
+Contains data from years 2002 to 2018 (joint leave days until
+2018).
 
 This function is not exported by default, but exportable.
 
@@ -1737,7 +1777,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Calendar-I
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Calendar-Indonesia-Holiday>.
+Source repository is at L<https://github.com/sharyanto/perl-Calendar-Indonesia-Holiday>.
 
 =head1 BUGS
 
